/* eslint-env jest */

const { runPlugins } = require("./helpers");

const plugin_ = require("../custom-props");
const plugin = (x) => plugin_(x, { transform: (x) => `token(${x})` });

it("removes interpolation inside custom property reassignment", () => {
  const actual = runPlugins(
    `
    --custom-property-1: #{$color-brand};
    .class1, .class2 {
      /*! @css-var-fallback border-radius */
      --custom-property-2: #{$color-brand};
    }
  `,
    [plugin(["color-brand"])]
  );
  expect(actual).toEqual(
    `
    --custom-property-1: token(colorBrand);
    .class1, .class2 {
      /*! @css-var-fallback border-radius */
      --custom-property-2: token(colorBrand);
    }
  `
  );
});

it("ignores interpolation outside custom property reassignments", () => {
  const actual = runPlugins(
    `
    color: #{$color-brand};
  `,
    [plugin(["color-brand"])]
  );
  expect(actual).toEqual(
    `
    color: #{$color-brand};
  `
  );
});

it("ignores invalid tokens", () => {
  const actual = runPlugins(
    `
    --custom-property-1: #{$color-brand};
    --custom-property-2: #{$border-width} 0 0 #{$color-brand};
  `,
    [plugin(["border-width"])]
  );
  expect(actual).toEqual(
    `
    --custom-property-1: #{$color-brand};
    --custom-property-2: token(borderWidth) 0 0 #{$color-brand};
  `
  );
});

it("removes multiple interpolations inside custom property reassignment", () => {
  const actual = runPlugins(
    `
    --custom-property-1: #{$border-width} 0 0 #{$color-brand};
  `,
    [plugin(["border-width", "color-brand"])]
  );
  expect(actual).toEqual(
    `
    --custom-property-1: token(borderWidth) 0 0 token(colorBrand);
  `
  );
});

it("circles", () => {
  const actual = runPlugins(
    `/**
 * @summary Circle container for icons
 * @selector .slds-icon_container_circle
 * @restrict .slds-icon_container
 */
.slds-icon_container_circle,
.slds-icon__container_circle,
.slds-icon_container--circle,
.slds-icon__container--circle {
  /*! @css-var-fallback border-radius */
  --slds-c-icon-radius-border: #{$border-radius-circle};
  padding: $spacing-x-small;
}`,
    [plugin(["border-radius-circle", "spacing-x-small"])]
  );
  expect(actual).toEqual(
    `/**
 * @summary Circle container for icons
 * @selector .slds-icon_container_circle
 * @restrict .slds-icon_container
 */
.slds-icon_container_circle,
.slds-icon__container_circle,
.slds-icon_container--circle,
.slds-icon__container--circle {
  /*! @css-var-fallback border-radius */
  --slds-c-icon-radius-border: token(borderRadiusCircle);
  padding: $spacing-x-small;
}`
  );
});

it("ignores custom property reassignment without interpolation", () => {
  const actual = runPlugins(
    `
    --custom-property-1: $color-brand;
    --custom-property-2: red;
  `,
    [plugin(["color-brand"])]
  );
  expect(actual).toEqual(
    `
    --custom-property-1: $color-brand;
    --custom-property-2: red;
  `
  );
});

it("ignore interpolations inside functions", () => {
  const actual = runPlugins(
    `
    @mixin input-focus-active {
  /*! @css-var-fallback border-color */
  --slds-c-input-color-border: var(--slds-c-input-color-border-focus, var(--sds-c-input-color-border-focus, #{$color-border-input-active}));
  }
  `,
    [plugin(["color-border-input-active"])]
  );
  expect(actual).toEqual(
    `
    @mixin input-focus-active {
  /*! @css-var-fallback border-color */
  --slds-c-input-color-border: var(--slds-c-input-color-border-focus, var(--sds-c-input-color-border-focus, #{$color-border-input-active}));
  }
  `
  );
});

it("ignore previously tokenized values", () => {
  const actual = runPlugins(
    `
    @mixin input-focus-active {
  /*! @css-var-fallback border-color */
  --slds-c-input-color-border: token("var(--slds-c-input-color-border-focus, var(--sds-c-input-color-border-focus, "+colorBorderInputActive+"))");
  }
  `,
    [plugin(["color-border-input-active"])]
  );
  expect(actual).toEqual(
    `
    @mixin input-focus-active {
  /*! @css-var-fallback border-color */
  --slds-c-input-color-border: token("var(--slds-c-input-color-border-focus, var(--sds-c-input-color-border-focus, "+colorBorderInputActive+"))");
  }
  `
  );
});
